@@ -5,7 +5,7 @@ from openride.core.numba import transform_vertices
 import copy
 import numpy as np
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from shapely import geometry
 from typing import List, Union, TYPE_CHECKING
 
@@ -16,7 +16,7 @@ if TYPE_CHECKING:
 @dataclass
 class Polygon(Geometry):
 
-    vertices: Union[np.ndarray, List[Point]] = np.empty((0, 3))
+    vertices: Union[np.ndarray, List[Point]] = field(default_factory=list)
 
     def __post_init__(self):
 
