@@ -9,9 +9,7 @@ import numpy as np
 
 @dataclass
 class Hero:
-    bounding_box: ride.BoundingBox = ride.BoundingBox(
-        ride.Point(0, 0, 0.8), rotation=ride.Rotation(), size=ride.Size(2.3, 0.9, 0.8)
-    )
+    bounding_box: ride.BoundingBox
     max_velocity: float = 50.0
 
     def __post_init__(self):
@@ -126,7 +124,12 @@ class City:
 
 def main():
 
-    hero = Hero()
+    hero = Hero(
+        ride.BoundingBox(
+            ride.Point(0, 0, 0.8), 
+            rotation=ride.Rotation(), 
+            size=ride.Size(2.3, 0.9, 0.8),
+        ))
     city = City(size=220)
 
     viewer = ride.Viewer(mouse_camera_interactions=False)
