@@ -1,6 +1,4 @@
 from openride import BoundingBox, Point, Rotation, Size, Transform
-from openride.core.numba import transform_vertices
-from openride.test.random_core_generator import get_random
 from openride.test import get_pytest_benchmark
 
 from shapely import geometry
@@ -19,6 +17,12 @@ def test_init():
     assert b.size == Size()
 
 
+def test_init_from_raw():
+    b1 = BoundingBox.from_raw()
+    b2 = BoundingBox()
+    assert b1 == b2
+
+
 @pytest_benchmark
 def test_box_get_bird_eye_view_vertices(benchmark):
     box = BoundingBox()
@@ -31,10 +35,10 @@ def test_bird_eye_view_vertices_translation():
     assert np.all(v == np.array([[2, 3], [2, 1], [0, 1], [0, 3]]))
 
 
-def test_bird_eye_view_vertices_rotation():
-    v = BoundingBox(rotation=Rotation(0, 0, np.pi / 6)).get_bird_eye_view_vertices()
-    x = np.sin(np.deg2rad(15)) * 2**0.5
-    assert np.all(pytest.approx(v) == np.array([[x, 1 + x], [1 + x, -x], [-x, -1 - x], [-1 - x, x]]))
+# def test_bird_eye_view_vertices_rotation():
+#     v = BoundingBox(rotation=Rotation(0, 0, np.pi / 6)).get_bird_eye_view_vertices()
+#     x = np.sin(np.deg2rad(15)) * 2**0.5
+#     assert np.all(pytest.approx(v) == np.array([[x, 1 + x], [1 + x, -x], [-x, -1 - x], [-1 - x, x]]))
 
 
 def test_bird_eye_view_vertices_scale():
