@@ -75,3 +75,9 @@ def test_matrix_mul_inverse_equals_identity():
         inv = tf.get_inverse_matrix()
         res = mat @ inv
         assert res == pytest.approx(np.eye(4))
+
+
+def test_init_from_6dof():
+    tf1 = Transform.from_6dof()
+    tf2 = Transform()
+    assert tf1 == tf2
